from bioservices.services import Service, WSDLService, RESTService, REST
from nose.plugins.attrib import attr

class test_Service(Service):
    def __init__(self):
        super(test_Service, self).__init__("test", "http://www.uniprot.org", verbose=False)
        self.url
        self.easyXMLConversion

    def test_easyXML(self):
        self.easyXML("<xml><id></id></xml>")

    @attr('skip')
    def test_pubmed(self):
        self.pubmed("24064416")


class test_WSDLService(WSDLService):
    def __init__(self):
        super(test_WSDLService, self).__init__("test",
            "http://biomodels.caltech.edu/services/BioModelsWebServices?wsdl", 
            verbose=False)

    def test_methods(self):
        self.wsdl_methods



class test_RESTService(RESTService):
    def __init__(self):
        super(test_RESTService, self).__init__("test",
            "http://www.uniprot.org", 
            verbose=False)

    def test_request(self):
        try:
            self.request("dummy")
            assert False
        except:
            assert True



from bioservices import OmniPath
from nose.plugins.attrib import attr


o = OmniPath(cache=True)


def test_omnipath():
    #o.get_info()
    o.get_about()

def test_net():
    o.get_network()


def test_inter():
    o.get_interactions()
    o.get_interactions("P00533")
    o.get_interactions(["P00533"])
    o.get_interactions("P00533,O15177,Q96FE5", frmt='json')
    o.get_interactions("P00533", frmt='json', fields=['sources', 'references'])

    try:
        o.get_interactions(00553)
        assert False
    except:
        assert True

def test_ptms():
    o.get_ptms()
    o.get_ptms("P00533")
    o.get_ptms(["P00533"])
    o.get_ptms("P00533", frmt='json')
    o.get_ptms("P00533", frmt='json', fields=['sources', 'references'])
    
    try:
        o.get_ptms(00553)
        assert False
    except:
        assert True

def test_get_resources():
    res = o.get_resources()

@attr('skip_travis')
def test_info():
    o.get_info()




from bioservices.rhea import Rhea
from nose.plugins.attrib import attr


def test_rhea():
    rhea = Rhea()
    r1 = rhea.search("caffeine")
    r1= rhea.search("caffeine", frmt="cmlreact")
    r2 = rhea.search("caffeine", frmt="biopax2")
    try:
        rhea.search("caffeine", frmt="biopaxddddddd2")
        assert False
    except:
        assert True

    rhea.entry(10280, "cmlreact")

    rhea.entry(10280, "biopax2")

    rhea.entry(10090, "rxn")

    try:
        rhea.entry(10090, "ggg")
        assert False
    except:
        assert True








from bioservices import RNASEQ_EBI


r = RNASEQ_EBI(cache=False)
assert 'homo_sapiens' in r.organisms


def test1():

    r.get_run_by_organism("homo_sapiens", "tsv")
    r.get_run_by_organism("homo_sapiens", "json")

    r.get_run_by_organism("homo_sapiens",condition="central nervous system")

def test2():

    r.get_run_by_study("SRP033494", mapping_quality=90, frmt='tsv')

def test3():
    res = r.get_study("SRP033494", "tsv")


    res = r.get_study("SRP033494", frmt="json")
    assert res[0]['STUDY_ID'] == "SRP033494"

def test4():
    try:
        import pandas
        res = r.get_studies_by_organism("arabidopsis_thaliana", frmt='tsv')
        studies = res['STUDY_ID'].values
    except:
        res = r.get_studies_by_organism("arabidopsis_thaliana", frmt='tsv')
        studies = [x[0] for x in res[1:]]


def test5():
    r.get_sample_attribute_per_run("SRR805786")
    r.get_sample_attribute_per_run("SRR805786", frmt='tsv')

    r.get_sample_attribute_per_study("SRP020492")
    r.get_sample_attribute_per_study("SRP020492", frmt='tsv')

    r.get_sample_attribute_per_study("SRP020492")
    r.get_sample_attribute_per_study("SRP020492", frmt='tsv')

def test_get_run():
    res = r.get_run("SRR1042759")
    assert res[0]['RUN_IDS'] == "SRR1042759"



# -*- coding: utf-8 -*-
__revision__ = "$Id$"
import os
from setuptools import setup, find_packages
import glob


_MAJOR               = 1
_MINOR               = 4
_MICRO               = 17
version              = '%d.%d.%d' % (_MAJOR, _MINOR, _MICRO)
release              = '%d.%d' % (_MAJOR, _MINOR)

metainfo = {
    'authors': {
        'Cokelaer':('Thomas Cokelaer','cokelaer@ebi.ac.uk'),
        },
    'version': version,
    'license' : 'GPL',
    'download_url' : ['http://pypi.python.org/pypi/bioservices'],
    'url' : ['http://pypi.python.org/pypi/bioservices'],
    'bugtrack_url': 'https://github.com/cokelaer/bioservices/issues',
    'description':'Access to Biological Web Services from Python' ,
    'platforms' : ['Linux', 'Unix', 'MacOsX', 'Windows'],
    'keywords' : [
        "BioServices", "WebServices", "Biology", "BioDBNet", "ChEBI", "UniChem", "Kegg", "KEGG", "BioModels",
        "EUtils", "UniProt", "PICR", "ArrayExpress", "MUSCLE", "QuickGO", "PDB", "PSICQUIC", "Blast",
        "BioMART", "BioGRID", "MIRIAM", "BioMart", "GeneProf", "ChEMBL", "ChemSpider", 
        "HGNC", "PathwayCommons", "Rhea", "Ensembl"],
    'classifiers' : [
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 2.7',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Scientific/Engineering :: Bio-Informatics',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'Topic :: Scientific/Engineering :: Mathematics',
          'Topic :: Scientific/Engineering :: Physics']
    }


with open('README.rst') as f:
    readme = f.read()
with open('HISTORY.rst') as f:
    history = f.read()



on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

# sphinx-gallery and numpydoc are used for the doc only.
# Could have a if on_rtd
install_requires = ["grequests", "requests",
        "requests_cache", "easydev>=0.9.7", "beautifulsoup4", "xmltodict",
        "suds-jurko", "appdirs", 'wrapt'],



setup(
    name             = 'bioservices',
    version          = version,
    maintainer       = metainfo['authors']['Cokelaer'][0],
    maintainer_email = metainfo['authors']['Cokelaer'][1],
    author           = metainfo['authors']['Cokelaer'][0],
    author_email     = metainfo['authors']['Cokelaer'][1],
    long_description = readme + '\n\n' + history,
    keywords         = metainfo['keywords'],
    description = metainfo['description'],
    license          = metainfo['license'],
    platforms        = metainfo['platforms'],
    url              = metainfo['url'],
    download_url     = metainfo['download_url'],
    classifiers      = metainfo['classifiers'],

    # package installation
    package_dir = {'':'src'},
    packages = ['bioservices', 'bioservices.apps', 'bioservices.mapping'],
    #package_dir  = package_dir,

    # If user of python2.6 ordereddict must be installed manually
    install_requires = install_requires,
    )


